UnicodeString

Struct UnicodeString 

pub struct UnicodeString<'a> { /* private fields */ }
A borrowed wrapper for a Windows UNICODE_STRING.

Implementations

Source

impl<'a> UnicodeString<'a>

pub fn new(s: &'a WStr) -> ConvertResult<Self>

Creates a borrowed UNICODE_STRING wrapper for s.

Returns ConvertError::ConvertToUnicodeError if the input is too long for a UNICODE_STRING length field.

pub fn as_raw(&self) -> &UNICODE_STRING

Returns a shared reference to the raw UNICODE_STRING representation.

pub unsafe fn as_raw_mut(&mut self) -> &mut UNICODE_STRING

Returns a mutable reference to the raw UNICODE_STRING representation.

Safety

The returned value must not be modified in a way that makes it outlive or stop describing the borrowed WStr stored in this wrapper.

pub fn as_ptr(&self) -> *const UNICODE_STRING

Returns a raw pointer to the raw UNICODE_STRING representation.

pub fn as_wstr(&self) -> &'a WStr

Returns the borrowed WStr associated with this.

Methods from Deref<Target = WStr>

pub fn as_ptr(&self) -> *const u16

Returns a raw pointer to the first wide character.

pub fn is_empty(&self) -> bool

Returns true if the string is empty.

pub fn as_bytes(&self) -> &[u16]

Returns the u16 elements of the wide string, excluding the terminating NUL.

pub fn as_bytes_with_nul(&self) -> &[u16]

Returns the u16 elements of the wide string, including the terminating NUL.

pub fn as_u8_bytes(&self) -> &[u8]

Returns a byte view of the wide string, excluding the terminating NUL.

The returned bytes are the in-memory representation of the stored u16 code units. On Windows this corresponds to UTF-16LE bytes.

pub fn as_u8_bytes_with_nul(&self) -> &[u8]

Returns a byte view of the wide string, including the terminating NUL.

The returned bytes are the in-memory representation of the stored u16 code units, including the terminating NUL code unit.

pub fn len(&self) -> usize

Returns the length of bytes excluding the terminating NUL.

pub fn len_with_nul(&self) -> usize

Returns the length of bytes including the terminating NUL.

pub fn to_os_string(&self) -> OsString

Converts into an OsString.

The terminating NUL is not included in the returned value.